@@ -3,7 +3,7 @@ from pygame import gfxdraw
 import math
 
 from pygame_widgets.widget import WidgetBase
-from pygame_widgets import TextBox
+from pygame_widgets.textbox import TextBox
 
 
 class Slider(WidgetBase):
